@@ -3,4 +3,4 @@ class ClientUrls:
     NAV_USER='https://www.instagram.com/{}/'
     SEARCH_TAGS='https://www.instagram.com/explore/tags/{}/'
     FOLLOWERS_URL = 'https://www.instagram.com/{}/followers/'
-    HOME_URL =  'https://www.instagram.com/'
\ No newline at end of file
+    HOME_URL =  'https://instagram.com/'
\ No newline at end of file
